@@ -27,6 +27,17 @@
 #include "ui_optionen.h"
 #include <QSettings>
 
+/*!
+  Anzeigemoeglichkeiten fuer neu geladene Bilder
+*/ 
+enum DisplayMode {
+  DM_ORIGINAL,	//!< Bild in Originalgroesse anzeigen
+  DM_WIDTH,	//!< Bildbreite an Fenster anpassen
+  DM_MAXWIDTH,	//!< Bildbreite an Fenster anpassen, wenn Bild breiter
+  DM_HEIGHT,	//!< Bildhoehe an Fenster anpassen
+  DM_MAXHEIGHT	//!< Bildhoehe an Fenster anpassen, wenn Bild hoeher
+};
+
 //! \brief Einstellen der Optionen des Programms
 class Optionen : public QDialog {
   // Data area
@@ -41,6 +52,9 @@ class Optionen : public QDialog {
   void accept();
   void selectDbPath();
 
+  signals:
+  void setDefaultZoom(DisplayMode);
+
   private:
   Q_OBJECT
 };
